@@ -28,7 +28,7 @@ fieldhash my %stt_file      => 'stt_file';
 fieldhash my %timeout       => 'timeout';
 fieldhash my %type          => 'type';
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 # --------------------------------------------------
 
@@ -310,7 +310,7 @@ These are in the scripts/ directory.
 
 =item o code.attributes2html.pl
 
-Convert data/code.attributes.csv to data/code.attributes.html.
+Generate both data/code.attributes.csv and data/code.attributes.html.
 
 =item o dot2lex.pl
 
@@ -754,6 +754,10 @@ Get or set the value which determines what type of 'stt_file' is read.
 
 The lexer and the parser each has an FAQ: L<Lexer|GraphViz2::Marpa::Lexer/FAQ>, and L<Parser|GraphViz2::Marpa::Parser/FAQ>.
 
+=head2 What is the homepage of Marpa?
+
+L<http://jeffreykegler.github.com/Marpa-web-site/>.
+
 =head2 Why do I get error messages like the following?
 
 	Error: <stdin>:1: syntax error near line 1
